/*! npm.im/video-canvas */
function Intervalometer (cb) {
	var rafId;
	var previousLoopTime;
	function loop(now) {
		// must be requested before cb() because that might call .stop()
		rafId = requestAnimationFrame(loop);
		cb(now - (previousLoopTime || now)); // ms since last call. 0 on start()
		previousLoopTime = now;
	}
	return {
		start: function start() {
			if (!rafId) { // prevent double starts
				loop(0);
			}
		},
		stop: function stop() {
			cancelAnimationFrame(rafId);
			rafId = null;
			previousLoopTime = 0;
		}
	};
};

function index (video, opts) {
	if ( opts === void 0 ) opts = {};

	var canvas = opts.canvas || document.createElement('canvas');
	var ctx = canvas.getContext('2d');

	var drawCall = opts.drawCall || function () {
		ctx.drawImage(video, 0, 0, canvas.width, canvas.height);
	};

	if (opts.updateSize !== false) {
		var updateSize = function () {
			canvas.width = video.videoWidth;
			canvas.height = video.height;
		};
		video.addEventListener('loadedmetadata', updateSize);
		updateSize();
	}

	var updater = new Intervalometer(function () { return drawCall(ctx, video); });
	video.addEventListener('play', updater.start);
	video.addEventListener('pause', updater.stop);
	video.addEventListener('error', updater.stop);
	if (!video.paused) {
		updater.start();
	}
	return canvas;
};

export default index;